# CHANGELOG

## 0.2a0
* Added functions:
    * wait_for_edge
    * event_detected
    * add_event_detect
    * add_event_callback
    * remove_event_detect
* Added PWM  class
* `VERBOSE` is now set to `True` by default
* Added `example.py`

## 0.1.0a0
* Initial release
